/*
 * RubricaServlet.java
 *
 * Created on 28 agosto 2004, 10.46
 */

package rubricaWebUi;

import java.io.*;
import java.net.*;

import javax.servlet.*;
import javax.servlet.http.*;

import rubricaLib.*;
import entityLib.*;
import exceptionLib.*;

/**
 *
 * @author  gdestri
 * @version
 */
public class RubricaServlet extends HttpServlet {
    
    GestoreMemoriaRubrica agenda = new GestoreMemoriaRubrica();
    
    /** Initializes the servlet.
     */
    public void init(ServletConfig config) throws ServletException {
        super.init(config);
        
    }
    
    /** Destroys the servlet.
     */
    public void destroy() {
        agenda = null;
    }
    
    /** Processes requests for both HTTP <code>GET</code> and <code>POST</code> methods.
     * @param request servlet request
     * @param response servlet response
     */
    protected void processRequest(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException {
        
        Persona temporaneo = null;
        
        // riceve i parametri dalla form HTML
        String nomeString = request.getParameter("nomeText");
        String cognomeString = request.getParameter("cognomeText");
        String numtelString = request.getParameter("numtelText");
        
        // caso di ricerca per nome
        if (request.getParameter("nomeSubmit")!=null) {
            try {
                agenda.cercaPerNome(nomeString);
                temporaneo = agenda.getFirst();
            } catch(RubricaException eccezione) {
                temporaneo = new Persona("","NOT FOUND","");
            } // end catch
        }

        // caso di ricerca per cognome
        if (request.getParameter("cognomeSubmit")!=null) {
            try {
                agenda.cercaPerCognome(cognomeString);
                temporaneo = agenda.getFirst();
            } catch(RubricaException eccezione) {
                temporaneo = new Persona("","NOT FOUND","");
            } // end catch
        }

        // caso di ricerca per num tel
        if (request.getParameter("numtelSubmit")!=null) {
            try {
                agenda.cercaPerNumtel(numtelString);
                temporaneo = agenda.getFirst();
            } catch(RubricaException eccezione) {
                temporaneo = new Persona("","NOT FOUND","");
            } // end catch
        }

        // caso di avanzamento nel recordset
        if (request.getParameter("nextSubmit")!=null) {
            temporaneo = agenda.getNext();
            if (temporaneo == null) {
                temporaneo = new Persona("","NOT FOUND","");
            } // end if null
        }
        
        // caso di arretramento nel recordset
        if (request.getParameter("previousSubmit")!=null) {
            temporaneo = agenda.getPrevious();
            if (temporaneo == null) {
                temporaneo = new Persona("","NOT FOUND","");
            } // end if null
        }

        // richiesta del primo elemento
        if (request.getParameter("firstSubmit")!=null) {
            temporaneo = agenda.getFirst();
            if (temporaneo == null) {
                temporaneo = new Persona("","NOT FOUND","");
            } // end if null
        }

        // richiesta dell'ultimo elemento
        if (request.getParameter("lastSubmit")!=null) {
            temporaneo = agenda.getLast();
            if (temporaneo == null) {
                temporaneo = new Persona("","NOT FOUND","");
            } // end if null
        }

        // cancellazione elemento selezionato
        if (request.getParameter("cancellaSubmit")!=null) {
            int selezioneCorrente;
            temporaneo=new Persona("", "", "");
            selezioneCorrente = agenda.getPosizioneCorrente();
            agenda.cancella(selezioneCorrente);
        }
        
        // cancellazione elemento selezionato
        if (request.getParameter("inserisciSubmit")!=null) {
            temporaneo=new Persona(nomeString, cognomeString, numtelString);
            agenda.inserisciNuovo(temporaneo);
        }

        // rimpiazzo elemento selezionato
        if (request.getParameter("modificaSubmit")!=null) {
            int selezioneCorrente;
            selezioneCorrente = agenda.getPosizioneCorrente();
            temporaneo=new Persona(nomeString, cognomeString, numtelString);
            agenda.rimpiazza(temporaneo,selezioneCorrente);      
        }

        // rileva il numero di record presenti in memoria
        String numRecordString=new String(Integer.toString(agenda.getSize()));
        
        // rileva la posizione corrente
        String corPosString=new String(Integer.toString(agenda.getPosizioneCorrente()+1));
     
        // aggancia la variabile alla request con identificatore "numRecord" e "corPos"
        request.setAttribute("numRecord", numRecordString);
        request.setAttribute("corPos", corPosString);
        
        // aggancia l'oggetto alla request con identificatore "personaObj"
        request.setAttribute("personaObj", temporaneo);
        
        // e passa il controllo alla pagina JSP
        request.getRequestDispatcher("rubrica/rubrica.jsp").forward(request, response);

    }
    
    /** Handles the HTTP <code>GET</code> method.
     * @param request servlet request
     * @param response servlet response
     */
    protected void doGet(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException {
        processRequest(request, response);
    }
    
    /** Handles the HTTP <code>POST</code> method.
     * @param request servlet request
     * @param response servlet response
     */
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
    throws ServletException, IOException {
        processRequest(request, response);
    }
    
    /** Returns a short description of the servlet.
     */
    public String getServletInfo() {
        return "Short description";
    }
    
} // end class RubricaServlet